======================
LightFM Dataset helper
======================


.. image:: https://img.shields.io/pypi/v/lightfm_dataset_helper.svg
        :target: https://pypi.python.org/pypi/lightfm_dataset_helper

.. image:: https://img.shields.io/travis/Med-ELOMARI/lightfm_dataset_helper.svg
        :target: https://travis-ci.com/Med-ELOMARI/lightfm_dataset_helper

.. image:: https://readthedocs.org/projects/lightfm-dataset-helper/badge/?version=latest
        :target: https://lightfm-dataset-helper.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/Med-ELOMARI/lightfm_dataset_helper/shield.svg
     :target: https://pyup.io/repos/github/Med-ELOMARI/lightfm_dataset_helper/
     :alt: Updates



A small  helper for  preparing csv files for LightFM fitting


* Free software: MIT license
* Documentation: https://lightfm-dataset-helper.readthedocs.io.
